@@ -1,5 +1,7 @@
 import datetime
 import logging
+import uuid
+import json
 
 import httpx
 
@@ -14,6 +16,7 @@ from e2b.envd.api import ENVD_API_HEALTH_ROUTE, handle_envd_api_exception
 from e2b.envd.versions import ENVD_DEBUG_FALLBACK
 from e2b.exceptions import SandboxException, format_request_timeout_error
 from e2b.sandbox.main import SandboxOpts
+from e2b.sandbox.mcp import McpServer
 from e2b.sandbox.sandbox_api import SandboxMetrics
 from e2b.sandbox.utils import class_method_variant
 from e2b.sandbox_sync.filesystem.filesystem import Filesystem
@@ -117,6 +120,7 @@ class Sandbox(SandboxApi):
             self.envd_api_url,
             self.connection_config,
             self._transport.pool,
+            self._envd_version,
         )
 
     def is_running(self, request_timeout: Optional[float] = None) -> bool:
@@ -508,6 +512,7 @@ class Sandbox(SandboxApi):
         envs: Optional[Dict[str, str]] = None,
         secure: bool = True,
         allow_internet_access: bool = True,
+        mcp: Optional[McpServer] = None,
         **opts: Unpack[ApiParams],
     ) -> Self:
         """
@@ -524,12 +529,19 @@ class Sandbox(SandboxApi):
         :param envs: Custom environment variables for the sandbox
         :param secure: Envd is secured with access token and cannot be used without it, defaults to `True`.
         :param allow_internet_access: Allow sandbox to access the internet, defaults to `True`.
+        :param mcp: MCP server to enable in the sandbox
 
         :return: A Sandbox instance for the new sandbox
 
         Use this method instead of using the constructor to create a new sandbox.
         """
-        return cls._create(
+
+        if not template and mcp is not None:
+            template = cls.default_mcp_template
+        elif not template:
+            template = cls.default_template
+
+        sandbox = cls._create(
             template=template,
             auto_pause=auto_pause,
             timeout=timeout,
@@ -537,9 +549,24 @@ class Sandbox(SandboxApi):
             envs=envs,
             secure=secure,
             allow_internet_access=allow_internet_access,
+            mcp=mcp,
             **opts,
         )
 
+        if mcp is not None:
+            token = str(uuid.uuid4())
+            sandbox._mcp_token = token
+
+            res = sandbox.commands.run(
+                f"mcp-gateway --config '{json.dumps(mcp)}'",
+                user="root",
+                envs={"GATEWAY_ACCESS_TOKEN": token},
+            )
+            if res.exit_code != 0:
+                raise Exception(f"Failed to start MCP gateway: {res.stderr}")
+
+        return sandbox
+
     @overload
     def beta_pause(
         self,
@@ -586,6 +613,18 @@ class Sandbox(SandboxApi):
             **opts,
         )
 
+    def beta_get_mcp_token(self) -> Optional[str]:
+        """
+        [BETA] This feature is in beta and may change in the future.
+
+        Get the MCP token for the sandbox.
+
+        :return: MCP token for the sandbox, or None if MCP is not enabled.
+        """
+        if not self._mcp_token:
+            self._mcp_token = self.files.read("/etc/mcp-gateway/.token", user="root")
+        return self._mcp_token
+
     @classmethod
     def _cls_connect(
         cls,
@@ -625,6 +664,7 @@ class Sandbox(SandboxApi):
         envs: Optional[Dict[str, str]],
         secure: bool,
         allow_internet_access: bool,
+        mcp: Optional[McpServer] = None,
         **opts: Unpack[ApiParams],
     ) -> Self:
         extra_sandbox_headers = {}
@@ -644,6 +684,7 @@ class Sandbox(SandboxApi):
                 env_vars=envs,
                 secure=secure,
                 allow_internet_access=allow_internet_access,
+                mcp=mcp,
                 **opts,
             )
 
